//
//  QNMediaFaceCheck.m
//  QNDoraKit
//
//  Created by 何云旗 on 2021/6/4.
//

#import "QNMediaFaceCheck.h"
#import <QNDoraKit/QNDoraKit.h>

#import <sys/utsname.h>

#define QND_RGBCOLOR(r,g,b) [UIColor colorWithRed:(r)/255.0 green:(g)/255.0 blue:(b)/255.0 alpha:1]
#define QND_RGBCOLOR_ALPHA(r,g,b,a) [UIColor colorWithRed:(r)/255.0 green:(g)/255.0 blue:(b)/255.0 alpha:(a)]

#define COLOR_WARN "990000" //47，156，250
#define QND_FaceCheckName @"光线活体人脸核验"

@interface QNMediaFaceCheck()<QNDoraFaceCheckDelegate>
@property (nonatomic, strong)UIView *preView;
@property (nonatomic, strong)UIImageView *mask;
@property (nonatomic, strong)UIView * back;
@property (nonatomic, strong)UILabel * noteMessage;
@property (nonatomic, strong)UIView *navView;

@property (nonatomic, strong)UIButton * cancelBtn;
@property (nonatomic, strong)UIWindow *window;

@property (nonatomic, strong)QNDoraFaceCheck *faceCheck;



@end

@implementation QNMediaFaceCheck

+ (QNMediaFaceCheck *)shared {
    static QNMediaFaceCheck *sharedInstance;
    static dispatch_once_t onceToken;
    dispatch_once(&onceToken, ^{
        sharedInstance = [[QNMediaFaceCheck alloc] init];
        sharedInstance.faceCheck = [QNDoraFaceCheck shared];
    });
    return sharedInstance;
}

- (BOOL)config{
    self.back = [[UIView alloc] initWithFrame:[UIScreen mainScreen].bounds];
    QNDoraLiveConfiguration *config = [[QNDoraLiveConfiguration alloc] initWithPeriod:-1 brightness:-1];
    self.faceCheck.delegate = self;
    
    [self setupUI];
    BOOL result = [_faceCheck configWithPreView:self.preView mask:self.mask configuration:config];
    
    //必须在initWithPreView 之后添加视图方可生效
    [self.back addSubview:self.preView];
    [self.back addSubview:self.mask];
    
    return result;
}


- (void)openDebug{
    [_faceCheck openDebug];
}

- (BOOL)startWithToken:(NSString *)token
                taskId:(NSString *)taskId{
    BOOL result = [_faceCheck startWithToken:token taskId:taskId];
    if (result) {
        self.noteMessage.text = @"状态提示";
        
        self.window.windowLevel = UIWindowLevelNormal+1;
        [self.window makeKeyAndVisible];
    }
    return result;
}

- (void)stop {
    self.noteMessage.text = @"状态栏";
    [_faceCheck stop];
}

- (void)destroy {
    [_faceCheck destroy];
}

- (NSString *)getVersionInfo {
    return [_faceCheck getVersionInfo];
}

#pragma mark Private

- (void)setupUI {
    self.window = [[UIWindow alloc] initWithFrame:[UIScreen mainScreen].bounds];
    [self.window addSubview:self.back];
    

    UILabel * flashLabel = [[UILabel alloc] init];
    flashLabel.text = QND_FaceCheckName;
    flashLabel.textAlignment = NSTextAlignmentCenter;
    flashLabel.font = [UIFont systemFontOfSize:18];
    flashLabel.textColor = [UIColor whiteColor];
    
    self.preView = [[UIView alloc] init];
    self.mask = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"wbbg1"]];
    self.mask.frame = self.back.bounds;
    //计算预览框大小
    CGFloat width = [UIScreen mainScreen].bounds.size.width;
    CGFloat vH = [UIScreen mainScreen].bounds.size.height;
    CGFloat pX = 85;
    CGFloat pW = width -  2*pX;
    CGFloat pH = (pW)*16/9;
    CGFloat pY = (vH-pH)/2;
    CGRect  mCGRect = CGRectMake(pX, pY, pW, pH);//相机分辨率是1280 *720 ，32 *18
    self.preView.frame = mCGRect;
    
    self.navView = [[UIView alloc] init];
    self.navView.backgroundColor = QND_RGBCOLOR(47,156,250);
    self.navView.userInteractionEnabled = YES;
    self.back.userInteractionEnabled = YES;
    self.mask.userInteractionEnabled = YES;
    
    self.cancelBtn = [UIButton buttonWithType:UIButtonTypeSystem];
    [self.cancelBtn setTitle:@"取消" forState:UIControlStateNormal];
    [self.cancelBtn setTintColor:[UIColor whiteColor]];
    [self.cancelBtn addTarget:self action:@selector(cencelBtnAction) forControlEvents:UIControlEventTouchUpInside];
    
    self.navView.frame = CGRectMake(0, 0, self.mask.bounds.size.width, 84);
    flashLabel.frame = CGRectMake(self.mask.bounds.size.width/2-100, 30, 200, 44);
    self.cancelBtn.frame = CGRectMake(0, 40, 100, 34);
    [self.navView addSubview:flashLabel];
    [self.navView addSubview:self.cancelBtn];
    [self.mask addSubview:self.navView];
    
    
    self.noteMessage = [[UILabel alloc] initWithFrame:CGRectMake(0, self.navView.bounds.size.height + 30, self.mask.bounds.size.width, 24)];
    self.noteMessage.textAlignment = NSTextAlignmentCenter;     // 居中对齐
    self.noteMessage.font = [UIFont systemFontOfSize:28];
    self.noteMessage.textColor = QND_RGBCOLOR(47,156,250);
    self.noteMessage.text = @"状态栏";
    [self.mask addSubview:self.noteMessage];
    
    [self openDebug];
    
}

- (void)cencelBtnAction {
    self.window.hidden = YES;
    self.window = nil;
    [self stop];
    [self destroy];
}

#pragma mark - QNDoraFaceCheckDelegate

- (void)FaceCheckDidDetectStart:(QNDoraFaceCheck *)faceCheck {
    dispatch_async(dispatch_get_main_queue(), ^{
        self.noteMessage.text = @"开始检测";
    });
    
    if (self.delegate && [self.delegate respondsToSelector:@selector(MediaFaceCheckDidDetectStart:)]) {
        [self.delegate MediaFaceCheckDidDetectStart:self];
    }
}

- (void)FaceCheck:(QNDoraFaceCheck *)faceCheck didGetFaceCheckResult:(NSInteger)result {
    dispatch_async(dispatch_get_main_queue(), ^{
        switch (result) {
                break;
            case 1:
                self.noteMessage.text = @"未识别到人脸";
                break;
            case 2:
                self.noteMessage.text = @"请保持人脸在框中间";
                break;
            case 3:
                self.noteMessage.text = @"请靠近一点";
                break;
            case 4:
                self.noteMessage.text = @"离远一点";
                break;
            case 5:
                self.noteMessage.text = @"请不要抬头";
                break;
            case 6:
                self.noteMessage.text = @"请不要侧头";
                break;
            case 7:
                self.noteMessage.text = @"请不要低头";
                break;
            case 8:
                self.noteMessage.text = @"请不要遮挡人脸";
                break;
            case 9:
                self.noteMessage.text = @"未识别到人脸";
                break;
            default:
                break;
        }
    });
        
    if (self.delegate && [self.delegate respondsToSelector:@selector(MediaFaceCheck:didGetFaceCheckResult:)]) {
        [self.delegate MediaFaceCheck:self didGetFaceCheckResult:result];
    }
}

- (void)FaceCheckLightCheckFault:(QNDoraFaceCheck *)faceCheck {
    dispatch_async(dispatch_get_main_queue(), ^{
        self.noteMessage.text = @"光线太强，请前往较暗环境";
    });
    
    if (self.delegate && [self.delegate respondsToSelector:@selector(MediaFaceCheckLightCheckFault:)]) {
        [self.delegate MediaFaceCheckLightCheckFault:self];
    }
}

- (void)FaceCheckPrepareChangeScreenColor:(QNDoraFaceCheck *)faceCheck {
    dispatch_async(dispatch_get_main_queue(), ^{
        self.noteMessage.text = @"1.5s后开始，请保持不动";
    });
    
    if (self.delegate && [self.delegate respondsToSelector:@selector(MediaFaceCheckPrepareChangeScreenColor:)]) {
        [self.delegate MediaFaceCheckPrepareChangeScreenColor:self];
    }
}

- (void)FaceCheckStartChangeScreenColor:(QNDoraFaceCheck *)faceCheck {
    dispatch_async(dispatch_get_main_queue(), ^{
        self.noteMessage.text = @"开始反光验证";
    });
    
    
    if (self.delegate && [self.delegate respondsToSelector:@selector(MediaFaceCheckStartChangeScreenColor:)]) {
        [self.delegate MediaFaceCheckStartChangeScreenColor:self];
    }
}

- (void)FaceCheckStopChangeScreenColor:(QNDoraFaceCheck *)faceCheck {
    dispatch_async(dispatch_get_main_queue(), ^{
        self.noteMessage.text = @"屏幕颜色变化停止";
    });
    
    if (self.delegate && [self.delegate respondsToSelector:@selector(MediaFaceCheckStopChangeScreenColor:)]) {
        [self.delegate MediaFaceCheckStopChangeScreenColor:self];
    }
}

- (void)FaceCheckSendServer:(QNDoraFaceCheck *)faceCheck {
    dispatch_async(dispatch_get_main_queue(), ^{
        self.noteMessage.text = @"数据发送后台中";
    });
    
    if (self.delegate && [self.delegate respondsToSelector:@selector(MediaFaceCheckSendServer:)]) {
        [self.delegate MediaFaceCheckSendServer:self];
    }
}

- (void)FaceCheck:(QNDoraFaceCheck *)faceCheck didGetDetectResult:(NSDictionary *)resultDic error:(NSError *)error{
    dispatch_async(dispatch_get_main_queue(), ^{
        self.noteMessage.text = @"检测结束";
    });
    
    if (self.delegate && [self.delegate respondsToSelector:@selector(MediaFaceCheck:didGetDetectResult:error:)]) {
        [self.delegate MediaFaceCheck:self didGetDetectResult:resultDic error:error];
    }
}

- (void)FaceCheck:(QNDoraFaceCheck *)faceCheck didDetectFaultWithCode:(NSInteger)code {
    dispatch_async(dispatch_get_main_queue(), ^{
        switch (code) {
            case 10:
                
                self.noteMessage.text = @"网络或服务异常";
                break;
            case 11:
                self.noteMessage.text = @"图片采集失败";
                break;
            default:
                self.noteMessage.text = @"检测失败";
                break;
        }
    });
    if (self.delegate && [self.delegate respondsToSelector:@selector(MediaFaceCheck:didDetectFaultWithCode:)]) {
        [self.delegate MediaFaceCheck:self didDetectFaultWithCode:code];
    }
}

- (void)FaceCheck:(QNDoraFaceCheck *)faceCheck didGetBrightness:(float)bright {
    if (self.delegate && [self.delegate respondsToSelector:@selector(MediaFaceCheck:didGetBrightness:)]) {
        [self.delegate MediaFaceCheck:self didGetBrightness:bright];
    }
}

@end
