//
//  QNMediaFlashLiveDetection.h
//  QNDoraKit
//
//  Created by 何云旗 on 2021/6/9.
//

#import <Foundation/Foundation.h>
#import <UIKit/UIKit.h>

NS_ASSUME_NONNULL_BEGIN

@class QNMediaFlashLiveDetection;

@protocol QNMediaFlashLiveDetectionDelegate <NSObject>

/*!
 * @abstract 开始检测的回调
 *
 * @since v0.0.1
 */
- (void)MediaFlashLiveDetectionDidDetectStart:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection;

/*!
 * @abstract 检测提醒的回调
 *
 * @discussion result 1 未识别到人脸；2 人脸不在框内；3  人脸太小；4  人脸过大；5  抬头；6  侧脸；7  低头；8  遮挡；9  没有人脸
 *
 * @since v0.0.1
 */
- (void)MediaFlashLiveDetection:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection didGetFaceCheckResult:(NSInteger)result;

/*!
 * @abstract 光线太强，需要前往较暗环境的回调
 *
 * @since v0.0.1
 */
- (void)MediaFlashLiveDetectionLightCheckFault:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection;

/*!
 * @abstract 1.5s后开始屏幕变色的回调
 *
 * @since v0.0.1
 */
- (void)MediaFlashLiveDetectionPrepareChangeScreenColor:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection;

/*!
 * @abstract 开始屏幕变色的回调
 *
 * @since v0.0.1
 */
- (void)MediaFlashLiveDetectionStartChangeScreenColor:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection;

/*!
 * @abstract 停止屏幕变色的回调
 *
 * @since v0.0.1
 */
- (void)MediaFlashLiveDetectionStopChangeScreenColor:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection;

/*!
 * @abstract 开始发送图片到后台的回调
 *
 * @since v0.0.1
 */
- (void)MediaFlashLiveDetectionSendServer:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection;

/*!
 * @abstract 检测结果成功的回调
 *
 * @discussion 当前结果仅表示有图片上传成功，且没有网络失败的结果，具体成功需要分析 resultDic 的返回参数
 *
 * @since v0.0.1
 */
- (void)MediaFlashLiveDetection:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection didGetDetectResult:(NSDictionary *)resultDic;

/*!
 * @abstract 检测失败结果的回调
 *
 * @discussion code：10  网络或服务异常；11 ，图片采集失败
 *
 * @since v0.0.1
 */
- (void)MediaFlashLiveDetection:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection didDetectFaultWithCode:(NSInteger)code;

/*!
 * @abstract 获取亮度的回调
 *
 * @since v0.0.1
 */
- (void)MediaFlashLiveDetection:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection didGetBrightness:(float)bright;

@end

@interface QNMediaFlashLiveDetection : NSObject

@property (nonatomic, weak) id <QNMediaFlashLiveDetectionDelegate> delegate;
/*!
 * @abstract QNMediaFlashLiveDetection 单例方法
 *
 * @since v0.0.1
 */
+ (QNMediaFlashLiveDetection *)shared;

/*!
 * @abstract 初始化
 *
 * @since v0.0.1
 */
- (BOOL)config;

/*!
 * @abstract 是否开启 debug 模式
 *
 * @since v0.0.2
 */
- (void)openDebug;

/*!
 * @abstract 停止检测
 *
 * @since v0.0.1
 */
- (BOOL)startWithToken:(NSString *)token
                taskId:(NSString *)taskId;

/*!
 * @abstract 停止检测
 *
 * @since v0.0.1
 */
- (void)stop;

/*!
 * @abstract 销毁
 *
 * @since v0.0.1
 */
- (void)destroy;

/*!
 * @abstract 获取版本信息
 *
 * @since v0.0.1
 */
- (NSString *)getVersionInfo;

@end

NS_ASSUME_NONNULL_END
