//
//  TableViewController.m
//  QNRTCTestDemo
//
//  Created by hxiongan on 2018/8/15.
//  Copyright © 2018年 hxiongan. All rights reserved.
//

#import "TableViewController.h"
#import <Masonry.h>
#import "QNMediaFlashLiveDetection.h"
#import "QNMediaFaceCheck.h"
#import <CommonCrypto/CommonHMAC.h>
#import "AFNetworking.h"

@interface TableViewController () <UINavigationControllerDelegate,QNMediaFaceCheckDelegate,QNMediaFlashLiveDetectionDelegate>
@property (nonatomic, strong) NSMutableArray *allControllerArray;

@property (nonatomic, strong)QNMediaFaceCheck * mediaFaceCheck;
@property (nonatomic, strong)QNMediaFlashLiveDetection * flashLiveDetection;



@property (nonatomic, strong)NSString *token;
@property (nonatomic, strong)NSString *taskId;

@end

@implementation TableViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    [self setupAllControlles];
    
}

- (void)setupAllControlles {
    self.allControllerArray = [[NSMutableArray alloc] init];
    NSArray *detectionArray = @[
                             @{@"QNMediaFaceCheckViewController" : @"光线活体人脸核验，包含基本的功能点测试，支持设置界面所有开关"},
                             @{@"QNMediaFlashLiveDetectionViewController" : @"光线活体检测，包含基本的功能点测试，支持设置界面所有开关"},
                             ];

    [self.allControllerArray addObject:detectionArray];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}
-(void)viewWillAppear:(BOOL)animated{
    
    // token 比对成功后，再人脸对比会失效
    [self getDoraToken];
}

-(void)getDoraToken {
    #error 联系服务获取访问 token
    self.taskId = @"";
    self.token =  @"";
}



//HmacSHA1加密；
- (NSString *)HmacSha1:(NSString *)key data:(NSString *)data
{
    const char *cKey  = [key cStringUsingEncoding:NSASCIIStringEncoding];
    const char *cData = [data cStringUsingEncoding:NSASCIIStringEncoding];
    unsigned char cHMAC[CC_SHA1_DIGEST_LENGTH];
    CCHmac(kCCHmacAlgSHA1, cKey, strlen(cKey), cData, strlen(cData), cHMAC);
    NSData *HMAC = [[NSData alloc] initWithBytes:cHMAC length:sizeof(cHMAC)];
    
    NSString *hash = [HMAC base64EncodedStringWithOptions:0];//将加密结果进行一次BASE64编码。
    return hash;
}

//获取指定日期几天后的时间戳
- (NSString *)getDate:(NSDate *)currentDate day:(NSInteger)day {
    NSTimeInterval oneDay = 24 * 60 * 60;  // 一天一共有多少秒
    NSDate *appointDate = [currentDate initWithTimeIntervalSinceNow: +(oneDay * day)];
    
    NSDateFormatter *formatter = [[NSDateFormatter alloc] init] ;
    [formatter setDateStyle:NSDateFormatterMediumStyle];
    [formatter setTimeStyle:NSDateFormatterShortStyle];
    [formatter setDateFormat:@"YYYY-MM-dd HH:mm:ss"];
    NSTimeZone* timeZone = [NSTimeZone timeZoneWithName:@"Asia/Shanghai"];
    [formatter setTimeZone:timeZone];

    NSString *timeSp = [NSString stringWithFormat:@"%ld", (long)[appointDate timeIntervalSince1970]];
    return timeSp;
}


#pragma mark - Table view data source


- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView {
    return self.allControllerArray.count;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [[self.allControllerArray objectAtIndex:section] count];
}

static const int cLabelTag = 10;
static const int cDetailLabelTag = 11;

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"reuseIdentifier"];
    
    if (!cell) {
        cell = [[UITableViewCell alloc] initWithStyle:(UITableViewCellStyleSubtitle) reuseIdentifier:@"reuseIdentifier"];

        cell.accessoryType = UITableViewCellAccessoryDisclosureIndicator;
        UILabel *label = [[UILabel alloc] init];
        label.font = [UIFont systemFontOfSize:18];
        label.numberOfLines = 0;
        label.tag = cLabelTag;
        
        UILabel *detailLabel = [[UILabel alloc] init];
        detailLabel.font = [UIFont systemFontOfSize:14];
        detailLabel.numberOfLines = 0;
        detailLabel.tag = cDetailLabelTag;
        detailLabel.textColor = [UIColor grayColor];
        
        [cell.contentView addSubview:label];
        [cell.contentView addSubview:detailLabel];
        
        [label mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.top.equalTo(cell.contentView).offset(10);
            make.right.equalTo(cell.contentView).offset(-10);
        }];
        [detailLabel mas_makeConstraints:^(MASConstraintMaker *make) {
            make.left.right.equalTo(label);
            make.bottom.equalTo(cell.contentView).offset(-10);
            make.top.equalTo(label.mas_bottom).offset(10);
        }];
    }
    
    NSDictionary *dic = [[self.allControllerArray objectAtIndex:indexPath.section] objectAtIndex:indexPath.row];
    
    UILabel *label = [cell.contentView viewWithTag:cLabelTag];
    label.text = dic.allKeys[0];
    
    UILabel *detailLabel = [cell.contentView viewWithTag:cDetailLabelTag];
    detailLabel.text = dic[dic.allKeys[0]];
    
    return cell;
}

- (CGFloat)tableView:(UITableView *)tableView estimatedHeightForRowAtIndexPath:(nonnull NSIndexPath *)indexPath {
    return 60;
}

- (CGFloat)tableView:(UITableView *)tableView estimatedHeightForHeaderInSection:(NSInteger)section {
    return 44;
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return UITableViewAutomaticDimension;
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section {
    return UITableViewAutomaticDimension;
}

- (UIView *)tableView:(UITableView *)tableView viewForHeaderInSection:(NSInteger)section {
    static const int footerLabelTag = 123;
    
    UITableViewHeaderFooterView *headerView = [tableView dequeueReusableHeaderFooterViewWithIdentifier:@"header"];
    if (!headerView) {
        headerView = [[UITableViewHeaderFooterView alloc] initWithReuseIdentifier:@"header"];
        
        UILabel *label = [[UILabel alloc] init];
        label.tag = footerLabelTag;
        label.font = [UIFont systemFontOfSize:18];
        
        [headerView.contentView addSubview:label];
        headerView.contentView.backgroundColor = [UIColor groupTableViewBackgroundColor];
        [label mas_makeConstraints:^(MASConstraintMaker *make) {
            make.edges.equalTo(headerView.contentView).insets(UIEdgeInsetsMake(20, 10, 5, 10));
        }];
    }
    
    static NSString *headerTexts[] = {
        @"检测模块:",
    };
    UILabel *label = [headerView.contentView viewWithTag:footerLabelTag];
    label.text = headerTexts[section];

    return headerView;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(nonnull NSIndexPath *)indexPath {
    if (!self.taskId || !self.token || [self.taskId isEqualToString:@""] || [self.token isEqualToString:@""]) {
        dispatch_async(dispatch_get_main_queue(), ^{
            UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:@"结果" message:@"token 获取失败" delegate:nil cancelButtonTitle:@"知道了" otherButtonTitles:nil];
            [alertView show];
        });
        NSLog(@"auth error ");
        return;
    }
    switch (indexPath.row) {
        case 0:{
            self.mediaFaceCheck = [QNMediaFaceCheck shared];
            self.mediaFaceCheck.delegate = self;
            [self.mediaFaceCheck config];
            
            [self.mediaFaceCheck startWithToken:self.token taskId:self.taskId];
            break;
        }
        case 1:{
            self.flashLiveDetection = [QNMediaFlashLiveDetection shared];
            self.flashLiveDetection.delegate = self;
            [self.flashLiveDetection config];

            [self.flashLiveDetection startWithToken:self.token taskId:self.taskId];
            break;
        }
        default:
            break;
    }
}
#pragma mark - MediaFaceCheckDelegate

- (void)MediaFaceCheck:(QNMediaFaceCheck *)mediaFaceCheck didGetDetectResult:(NSDictionary *)resultDic error:(NSError *)error {
    NSLog(@"MediaFaceCheck:didGetDetectResult:%@ error:%@",resultDic,error);
    dispatch_async(dispatch_get_main_queue(), ^{
        UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:@"结果" message:[NSString stringWithFormat:@"result: %@ \nerror:%@",resultDic,error] delegate:nil cancelButtonTitle:@"知道了" otherButtonTitles:nil];
        [alertView show];
    });
    
}

- (void)MediaFaceCheck:(QNMediaFaceCheck *)mediaFaceCheck didDetectFaultWithCode:(NSInteger)code {
    NSLog(@"MediaFaceCheck:didDetectFaultWithCode:%d",code);
}

#pragma mark - QNMediaFlashLiveDetectionDelegate

- (void)MediaFlashLiveDetection:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection didGetDetectResult:(NSDictionary *)resultDic {
    NSLog(@"MediaFlashLiveDetection:didGetDetectResult:%@",resultDic);
    dispatch_async(dispatch_get_main_queue(), ^{
        UIAlertView *alertView = [[UIAlertView alloc] initWithTitle:@"结果" message:[NSString stringWithFormat:@"result: %@ \n",resultDic] delegate:nil cancelButtonTitle:@"知道了" otherButtonTitles:nil];
        [alertView show];
    });
}

- (void)MediaFlashLiveDetection:(QNMediaFlashLiveDetection *)mediaFlashLiveDetection didDetectFaultWithCode:(NSInteger)code {
    NSLog(@"MediaFaceCheck:didDetectFaultWithCode:%d",code);
}

@end
