#import <Foundation/Foundation.h>
#import <AVFoundation/AVFoundation.h>
#import <UIKit/UIKit.h>

@interface Result : NSObject
    @property (nonatomic) NSInteger errorcode;
    @property (nonatomic, copy) NSString * _Nullable errormsg;
    @property (nonatomic, copy) NSString * _Nullable session_id;
    @property (nonatomic) double score;
    @property (nonatomic) NSInteger pass_num;
    @property (nonatomic) NSInteger face_num;
@end
@interface Response : NSObject
    @property (nonatomic, strong) Result * _Nullable response;
    @property (nonatomic, copy) NSString * _Nullable request_id;
    - (nonnull instancetype)init ;
@end

@interface CameraConfig: NSObject
    @property int width;
    @property int height;
    @property  UIView *pView;
- (nonnull instancetype)initWithP:(UIView * _Nonnull)p ;
- (nonnull instancetype)init ;
@end
@interface FlashLivenessConfig: NSObject
    @property    int period ;
    @property     NSString* url;
    @property    int  brightness;
    @property(readonly)    int colorCounts;
    @property(readonly)    int pictureCounts;
    @property    bool debug ;
    @property(readonly)    int proxyType ;
@end



@interface RequestParams : NSObject
    @property (nonatomic, copy) NSString * _Null_unspecified url;
    @property (nonatomic, copy) NSString * _Null_unspecified body;
    @property (nonatomic, copy) NSMutableDictionary<NSString *, NSString *> * _Null_unspecified header;
    @property (nonatomic, copy) NSString * _Null_unspecified method;
    - (nonnull instancetype)initWithUrl:(NSString * _Nonnull)url body:(NSString * _Nonnull)body header:(NSMutableDictionary<NSString *, NSString *> * _Nonnull)header method:(NSString * _Nonnull)method ;
   
@end

@interface ExtraRequestParams : NSObject
    @property (nonatomic, copy) NSMutableDictionary * _Null_unspecified extraHeader;
    @property (nonatomic, copy) NSString *  extraTaskId;
-(nonnull instancetype)init:(NSDictionary<NSString *, NSString *> * _Nonnull)header id:(NSString * _Nonnull)id ;
- (nonnull instancetype)init ;
+ (nonnull instancetype)new ;
@end
@protocol FlashLivenessHeaderDelegate
    - (ExtraRequestParams * _Nonnull)getHeader:(RequestParams * _Nonnull)params ;
@end
@protocol FlashLivenessDelegate
    - (void)onDetectStart;
    - (void)onFaceCheckResult:(NSInteger)code;
    - (void)onLightCheckFault;
    - (void)onPrepareChangeScreenColor;
    - (void)onStartChangeScreenColor;
    - (void)onStopChangeScreenColor;
    - (void)onSendServer;
    - (void)onDetectResultWithScore:(double)score;
    - (void)onDetectResult:(Response * _Nonnull)data;
    - (void)onDetectFaultWithCode:(NSInteger)code;
    - (void)onGetBrightnessWithBright:(float)bright;
@end
@interface FlashLivenessDetection : NSObject<AVCaptureVideoDataOutputSampleBufferDelegate> {
    NSString *name;
    FlashLivenessConfig *mConfig;
    CameraConfig *mCameraConfig;
    bool isInited;
    int mStep;
    id<FlashLivenessDelegate> mCallback;
    double lastFrameTime;
    NSString *mImageStr;
}

@property (nonatomic, class, readonly) FlashLivenessDetection* shared;
+ (FlashLivenessDetection*)shared ;
+ (NSInteger)CODE_SUCCESS ;
@property (nonatomic, class, readonly) NSInteger CODE_SUCCESS;
+ (NSInteger)CODE_SUCCESS ;
@property (nonatomic, class, readonly) NSInteger CODE_ERROR_1;
+ (NSInteger)CODE_ERROR_1 ;
@property (nonatomic, class, readonly) NSInteger CODE_ERROR_2;
+ (NSInteger)CODE_ERROR_2;
@property (nonatomic, class, readonly) NSInteger CODE_ERROR_3;
+ (NSInteger)CODE_ERROR_3 ; 
@property (nonatomic, class, readonly) NSInteger CODE_ERROR_4;
+ (NSInteger)CODE_ERROR_4 ;
@property (nonatomic, class, readonly) NSInteger CODE_ERROR_5;
+ (NSInteger)CODE_ERROR_5 ;
@property (nonatomic, class, readonly) NSInteger CODE_ERROR_6;
+ (NSInteger)CODE_ERROR_6 ;
@property (nonatomic, class, readonly) NSInteger CODE_ERROR_7;
+ (NSInteger)CODE_ERROR_7 ;
@property (nonatomic, class, readonly) NSInteger CODE_ERROR_8;
+ (NSInteger)CODE_ERROR_8 ;
@property (nonatomic, class, readonly) NSInteger CODE_ERROR_9;
+ (NSInteger)CODE_ERROR_9 ;
@property (nonatomic, class, readonly) NSInteger CODE_ERROR_10;
+ (NSInteger)CODE_ERROR_10 ;
@property (nonatomic, class, readonly) NSInteger CODE_ERROR_11;
+ (NSInteger)CODE_ERROR_11 ;
-(bool)startInitModelWithCameraConfig:(CameraConfig * _Nonnull)cameraConfig mask:(UIImageView * _Nonnull)mask flashConfig:(FlashLivenessConfig * _Nonnull)flashConfig ;
- (BOOL)startDetectWithDelegate:(id <FlashLivenessDelegate> _Nonnull)delegate ;
- (void)stopDetect;
- (void)releaseModel;
- (NSString *)getVersion;
- (void)setSecureHeaderCreater:(id<FlashLivenessHeaderDelegate>) secureDelegate;
- (bool)openDebug;
- (NSString *)getLastImage;
+ (FlashLivenessDetection *)shared;
@end

